@@ -51,15 +51,6 @@
 #  include <sys/time.h>
 #endif
 
-
-/* Work around a glib limitation: it doesn't set G_INLINE_FUNC on Win32. */
-#if defined(G_PLATFORM_WIN32)
-#  if defined(G_INLINE_FUNC)
-#     undef G_INLINE_FUNC
-#  endif
-#  define G_INLINE_FUNC static __inline
-#endif
-
 #ifndef ABS
 #  define ABS(x) (((x) >= 0) ? (x) : -(x))
 #endif
