@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2014-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2014-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -22,12 +22,14 @@
  *      Get disk information.
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include "vm_assert.h"
 #include "debug.h"
 #include "guestInfoInt.h"
 #include "str.h"
+#include "strutil.h"
 #include "posix.h"
 #include "file.h"
 #include "util.h"
@@ -68,7 +70,9 @@
    # define PATH_MAX 1024
 #endif
 
-#define LINUX_SYS_BLOCK_DIR "/sys/class/block"
+#define LINUX_SYS_CLASS_BLOCK_DIR "/sys/class/block"
+#define LINUX_SYS_DEV_BLOCK_DIR "/sys/dev/block"
+#define LINUX_PROC_SELF_MOUNTINFO "/proc/self/mountinfo"
 
 #define PCI_IDE         0x010100
 #define PCI_SATA_AHCI_1 0x010601
@@ -165,6 +169,46 @@ GuestInfoAddDeviceName(char *devName,
 }
 
 
+/*
+ ******************************************************************************
+ * GuestInfoCheckPci0 --                                                */ /**
+ *
+ * Check if this PCI device path does not contain a "label" file and happens
+ * to be PCI bus 0.
+ *
+ * @param[in]  pciDevPath  Path of the PCI device of interest.
+ * @param[in]  unit        Disk unit or device number (previously determined).
+ * @param[out] devName     Address of the buffer to receive device name.
+ * @param[in]  devMaxLen   Maximum length of the device buffer available.
+ *
+ * @return True if this disk device is on PCI bus 0 and the devName has
+ *         been filled in as scsi0:unit.
+ *
+ ******************************************************************************
+ */
+
+static Bool
+GuestInfoCheckPci0(const char *pciDevPath,
+                   const char *unit,
+                   char *devName,
+                   size_t devMaxLen)
+{
+   char *realPath = NULL;
+   Bool result = FALSE;
+
+   if((realPath = Posix_RealPath(pciDevPath)) == NULL) {
+      goto exit;
+   }
+   if (StrUtil_EndsWith(realPath, "/0000:00:10.0")) {
+      Str_Snprintf (devName, devMaxLen, "scsi0:%s", unit);
+      result = TRUE;
+   }
+   free(realPath);
+exit:
+   return result;
+}
+
+
 /*
  ******************************************************************************
  * GuestInfoGetPCIName --                                                */ /**
@@ -187,7 +231,7 @@ static void
 GuestInfoGetPCIName(const char *pciDevPath,
                     const char *unit,
                     char *devName,
-                    unsigned int devMaxLen)
+                    size_t devMaxLen)
 {
    char labelPath[PATH_MAX];
    FILE *labelFile;
@@ -197,8 +241,15 @@ GuestInfoGetPCIName(const char *pciDevPath,
    Str_Snprintf(labelPath, PATH_MAX, "%s/%s", pciDevPath, "label");
 
    if ((labelFile = fopen(labelPath, "r")) == NULL) {
-      g_debug("%s: unable to open \"label\" file for device %s.\n",
-              __FUNCTION__, pciDevPath);
+      /*
+       * Need to check if this might be the LSI Logic Parallel or BusLogic
+       * SCSI controller on PCI bus 0, in which case "label" is not expected.
+       */
+      if (errno != ENOENT ||
+          !GuestInfoCheckPci0(pciDevPath, unit, devName, devMaxLen)) {
+         g_debug("%s: unable to open \"label\" file for device %s.\n",
+                 __FUNCTION__, pciDevPath);
+      }
       return;
    }
    if (fgets(buffer, sizeof buffer, labelFile) == NULL) {
@@ -577,11 +628,12 @@ finished:
  * @param[in]     devNum     The number of the DiskDevName to be updated.
  *                           The diskDevNames is numbered  1, 2, ... as opposed
  *                           to array indexes which start at 0.
+ * @return TRUE if the device name for the disk has been determined.
  *
  ******************************************************************************
  */
 
-static void
+static Bool
 GuestInfoLinuxBlockDevice(const char *startPath,
                           PartitionEntryInt *partEntry,
                           int devNum)
@@ -596,6 +648,7 @@ GuestInfoLinuxBlockDevice(const char *startPath,
    char *unit = NULL;
    unsigned int devClass;
    char devName[DISK_DEVICE_NAME_SIZE];
+   Bool devNameSet;
 
    ASSERT(startPath);
    ASSERT(partEntry);
@@ -690,8 +743,10 @@ finished:
    g_clear_error(&gErr);
    g_free(unit);
    free(realPath);
+   devNameSet = devName[0] != '\0';
    g_debug("%s: Filesystem of interest found on device \"%s\"\n",
-          __FUNCTION__, devName[0] == '\0' ? "** unknown **" : devName);
+           __FUNCTION__, devNameSet ? devName : "** unknown **");
+   return devNameSet;
 }
 
 
@@ -736,7 +791,7 @@ GuestInfoIsLinuxLvmDevice(const char *fsName,
    if ((realPath = Posix_RealPath(fsName)) == NULL) {
       return FALSE;
    }
-   Str_Snprintf(slavesPath, PATH_MAX, "%s/%s/slaves", LINUX_SYS_BLOCK_DIR,
+   Str_Snprintf(slavesPath, PATH_MAX, "%s/%s/slaves", LINUX_SYS_CLASS_BLOCK_DIR,
                 strrchr(realPath, '/') + 1);
    free(realPath);
    if (!File_IsDirectory(slavesPath)) {
@@ -778,6 +833,70 @@ GuestInfoIsLinuxLvmDevice(const char *fsName,
    return TRUE;
 }
 
+
+/*
+ ******************************************************************************
+ * GuestInfoCheckDevRoot --
+ *
+ * Disks mounted on /dev/root are setup at boot time before the OS enumerates
+ * the PCI devices in /sys/class/block.  The device for /dev/root does not
+ * appear there.   Instead the PCI device info needs to be accessed through
+ * /sys/dev/block and the major and minor device number.  That can be extracted
+ * from the contents of /proc/self/mountinfo.
+ *
+ * The format of the lines in /proc/self/mountinfo can vary between Linux
+ * versions.
+ *
+ *    Field
+ *    -----
+ *      3     The major and minor number of the device in "m:n" format.
+ *   9 or 10  The fsName for this specific entry.
+ *
+ * @param[in]  fsName       Name of the filesystem device - i.e. /dev/root
+ * @param[in]  pathLen      Maximum size including terminating NUL character
+ *                          for the starting search path.
+ * @param[out] blockDevPath Starting path to begin the search for the "device"
+ *                          file if the major and minor number can be found.
+ * @return TRUE if the device major and minor numbers have been located and
+ *         blockDevPath has been filled in.
+ *
+ ******************************************************************************
+ */
+
+static Bool
+GuestInfoCheckDevRoot(const char *fsName,
+                      int pathLen,
+                      char *blockDevPath)
+{
+   FILE *mountinfo;
+   char buffer[BUFSIZ];
+   char pattern[128];
+
+   if ((mountinfo = fopen(LINUX_PROC_SELF_MOUNTINFO, "r")) == NULL) {
+      g_debug("%s: unable to open \"" LINUX_PROC_SELF_MOUNTINFO
+              "\": (%d) %s\n", __FUNCTION__, errno, strerror(errno));
+      return FALSE;
+   }
+   snprintf(pattern, sizeof pattern, " %s ", fsName);
+   /* Locate the "/dev/root" entry in /proc/self/mountinfo. */
+   while ((fgets(buffer, sizeof buffer, mountinfo)) != NULL) {
+      if (strstr(buffer, pattern) != NULL) {
+         char *savedPtr = NULL;
+         const char *majMinNo;
+
+         (void) strtok_r(buffer, " ", &savedPtr);
+         (void) strtok_r(NULL, " ", &savedPtr);
+         majMinNo = strtok_r(NULL, " ", &savedPtr);
+         Str_Snprintf(blockDevPath, pathLen, "%s/%s", LINUX_SYS_DEV_BLOCK_DIR,
+                      majMinNo);
+         fclose(mountinfo);
+         return TRUE;
+      }
+   }
+   fclose(mountinfo);
+   return FALSE;
+}
+
 #endif /* __linux__ */
 
 /*
@@ -833,10 +952,24 @@ GuestInfoGetDiskDevice(const char *fsName,
        * lookup; avoid at this time.
        */
       if (baseDevName != NULL && strcmp(partEntry->fsType, "zfs") != 0) {
-         Str_Snprintf(blockDevPath, PATH_MAX,  "%s/%s", LINUX_SYS_BLOCK_DIR,
-                      baseDevName + 1);
-         /* First and only disk device. */
-         GuestInfoLinuxBlockDevice(blockDevPath, partEntry, 1);
+         /*
+          * Have a single disk device associated with this mount point.  The
+          * majority of these will be handled by the basic Linux block device
+          * lookup.
+          */
+         Str_Snprintf(blockDevPath, sizeof blockDevPath,  "%s/%s",
+                      LINUX_SYS_CLASS_BLOCK_DIR, baseDevName + 1);
+         if (!GuestInfoLinuxBlockDevice(blockDevPath, partEntry, 1)) {
+            /*
+             * No device name was located.  This may be a pseudo device
+             * such as Photon's /dev/root.  Try a lookup based on the device
+             * major and minor number.
+             */
+            if (GuestInfoCheckDevRoot(fsName, sizeof blockDevPath,
+                                      blockDevPath)) {
+               GuestInfoLinuxBlockDevice(blockDevPath, partEntry, 1);
+            }
+         }
       }
    }
 
@@ -846,9 +979,9 @@ GuestInfoGetDiskDevice(const char *fsName,
     */
    for (indx = 0; indx < partEntry->diskDevCnt; indx++) {
       if (partEntry->diskDevNames[indx][0] == '\0') {
-         g_warning("%s: Missing disk device name; VMDK mapping unavailable "
-                   "for \"%s\", fsName: \"%s\"\n", __FUNCTION__,
-                   partEntry->name, fsName);
+         g_debug("%s: Missing disk device name; VMDK mapping unavailable "
+                 "for \"%s\", fsName: \"%s\"\n", __FUNCTION__,
+                 partEntry->name, fsName);
          partEntry->diskDevCnt = 0;
          free(partEntry->diskDevNames);
          partEntry->diskDevNames = NULL;
@@ -883,7 +1016,7 @@ GuestInfoGetDiskInfoWiper(Bool includeReserved,  // IN
    unsigned int partCount = 0;
    uint64 freeBytes = 0;
    uint64 totalBytes = 0;
-   unsigned int partNameSize = 0;
+   size_t partNameSize = 0;
    Bool success = FALSE;
    GuestDiskInfoInt *di;
 
